@@ -12,10 +12,10 @@ pub mod ansible_facts_request;
 pub use self::ansible_facts_request::AnsibleFactsRequest;
 pub mod appliance;
 pub use self::appliance::Appliance;
-pub mod appliance_pki;
-pub use self::appliance_pki::AppliancePki;
-pub mod appliance_pki_request;
-pub use self::appliance_pki_request::AppliancePkiRequest;
+pub mod appliance_public_key;
+pub use self::appliance_public_key::AppliancePublicKey;
+pub mod appliance_public_key_request;
+pub use self::appliance_public_key_request::AppliancePublicKeyRequest;
 pub mod appliance_request;
 pub use self::appliance_request::ApplianceRequest;
 pub mod artifact_types_enum;
@@ -32,6 +32,10 @@ pub mod camera_request;
 pub use self::camera_request::CameraRequest;
 pub mod camera_type_enum;
 pub use self::camera_type_enum::CameraTypeEnum;
+pub mod cloud_io_t_device;
+pub use self::cloud_io_t_device::CloudIoTDevice;
+pub mod cloud_io_t_device_request;
+pub use self::cloud_io_t_device_request::CloudIoTDeviceRequest;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
 pub mod detail_response;
@@ -46,16 +50,14 @@ pub mod event_source_enum;
 pub use self::event_source_enum::EventSourceEnum;
 pub mod event_type0c4_enum;
 pub use self::event_type0c4_enum::EventType0c4Enum;
-pub mod event_type_d9e_enum;
-pub use self::event_type_d9e_enum::EventTypeD9eEnum;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
 pub use self::experiment_device_config::ExperimentDeviceConfig;
 pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
-pub mod inline_response_403;
-pub use self::inline_response_403::InlineResponse403;
+pub mod inline_response_default;
+pub use self::inline_response_default::InlineResponseDefault;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
@@ -118,10 +120,16 @@ pub mod octoprint_python_request;
 pub use self::octoprint_python_request::OctoprintPythonRequest;
 pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
+pub mod paginated_ansible_facts_list;
+pub use self::paginated_ansible_facts_list::PaginatedAnsibleFactsList;
 pub mod paginated_appliance_list;
 pub use self::paginated_appliance_list::PaginatedApplianceList;
+pub mod paginated_appliance_public_key_list;
+pub use self::paginated_appliance_public_key_list::PaginatedAppliancePublicKeyList;
 pub mod paginated_camera_list;
 pub use self::paginated_camera_list::PaginatedCameraList;
+pub mod paginated_cloud_io_t_device_list;
+pub use self::paginated_cloud_io_t_device_list::PaginatedCloudIoTDeviceList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
 pub mod paginated_experiment_device_config_list;
@@ -162,10 +170,16 @@ pub mod patched_alert_bulk_request_request;
 pub use self::patched_alert_bulk_request_request::PatchedAlertBulkRequestRequest;
 pub mod patched_alert_request;
 pub use self::patched_alert_request::PatchedAlertRequest;
+pub mod patched_ansible_facts_request;
+pub use self::patched_ansible_facts_request::PatchedAnsibleFactsRequest;
+pub mod patched_appliance_public_key_request;
+pub use self::patched_appliance_public_key_request::PatchedAppliancePublicKeyRequest;
 pub mod patched_appliance_request;
 pub use self::patched_appliance_request::PatchedApplianceRequest;
 pub mod patched_camera_request;
 pub use self::patched_camera_request::PatchedCameraRequest;
+pub mod patched_cloud_io_t_device_request;
+pub use self::patched_cloud_io_t_device_request::PatchedCloudIoTDeviceRequest;
 pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
 pub mod patched_octo_print_device_request;
@@ -184,8 +198,8 @@ pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
 pub use self::print_job_event_request::PrintJobEventRequest;
-pub mod print_job_status_enum;
-pub use self::print_job_status_enum::PrintJobStatusEnum;
+pub mod print_job_event_type;
+pub use self::print_job_event_type::PrintJobEventType;
 pub mod print_nanny_plugin_event;
 pub use self::print_nanny_plugin_event::PrintNannyPluginEvent;
 pub mod print_nanny_plugin_event_event_type_enum;
